indexdb

package module
v0.1.26 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: MIT Imports: 5 Imported by: 0

README

tinywasm/indexdb

Project Badges

implementación de index dB con Websassembly compilado con go (golang)

Contributing

Documentation

Rendered for js/wasm

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InitDB added in v0.1.25

func InitDB(dbName string, idg idGenerator, logger func(...any), structTables ...any) *orm.DB

InitDB initializes the IndexedDB database and returns an *orm.DB instance.

Types

type IndexDBAdapter added in v0.1.24

type IndexDBAdapter struct {
	// contains filtered or unexported fields
}

func NewAdapter added in v0.1.24

func NewAdapter(dbName string, idg idGenerator, logger func(...any)) *IndexDBAdapter

NewAdapter creates a new IndexDBAdapter.

func (*IndexDBAdapter) Execute added in v0.1.24

func (d *IndexDBAdapter) Execute(q orm.Query, m orm.Model, factory func() orm.Model, each func(orm.Model)) error

Execute implements orm.Adapter for IndexDB.

func (*IndexDBAdapter) GetNewID added in v0.1.24

func (d *IndexDBAdapter) GetNewID() string

Helper to access the ID generator

func (*IndexDBAdapter) Initialize added in v0.1.25

func (d *IndexDBAdapter) Initialize(structTables ...any)

Initialize initializes the IndexedDB database and creates object stores based on the provided structs.

func (*IndexDBAdapter) TableExist added in v0.1.24

func (d *IndexDBAdapter) TableExist(table_name string) bool

TableExist checks if a table exists in the database

Directories

Path Synopsis

Jump to