Documentation
¶
Rendered for js/wasm
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type IndexDBAdapter ¶ added in v0.1.24
type IndexDBAdapter struct {
// contains filtered or unexported fields
}
func NewAdapter ¶ added in v0.1.24
func NewAdapter(dbName string, idg idGenerator, logger func(...any)) *IndexDBAdapter
NewAdapter creates a new IndexDBAdapter.
func (*IndexDBAdapter) Execute ¶ added in v0.1.24
func (d *IndexDBAdapter) Execute(q orm.Query, m orm.Model, factory func() orm.Model, each func(orm.Model)) error
Execute implements orm.Adapter for IndexDB.
func (*IndexDBAdapter) GetNewID ¶ added in v0.1.24
func (d *IndexDBAdapter) GetNewID() string
Helper to access the ID generator
func (*IndexDBAdapter) Initialize ¶ added in v0.1.25
func (d *IndexDBAdapter) Initialize(structTables ...any)
Initialize initializes the IndexedDB database and creates object stores based on the provided structs.
func (*IndexDBAdapter) TableExist ¶ added in v0.1.24
func (d *IndexDBAdapter) TableExist(table_name string) bool
TableExist checks if a table exists in the database
Click to show internal directories.
Click to hide internal directories.